@@ -490,12 +490,12 @@ where
         let mut rv = vec_3d::LineString3::default().with_connected(false);
         let z_comp = -distance_to_point_squared(&self.start_point, &self.cell_point).sqrt();
         rv.points
-            .push([self.start_point[0], self.start_point[1], z_comp].into());
+            .push([self.start_point[0], self.start_point[1], z_comp]);
 
         let z_comp = -distance_to_point_squared(&self.end_point, &self.cell_point).sqrt();
         // todo, don't insert end_point and then pop it again a few lines later..
         rv.points
-            .push([self.end_point[0], self.end_point[1], z_comp].into());
+            .push([self.end_point[0], self.end_point[1], z_comp]);
 
         // Apply the linear transformation to move start point of the segment to
         // the point with coordinates (0, 0) and the direction of the segment to
@@ -809,7 +809,7 @@ where
 
     /// Returns the line string as a iterator of lines
     #[must_use = "iterator adaptors are lazy and do nothing unless consumed"]
-    pub fn as_lines_iter(&self) -> Box<dyn Iterator<Item = Line2<T>> + '_> {
+    pub fn as_lines_iter<'a>(&'a self) -> Box<dyn Iterator<Item = Line2<T>> + 'a> {
         if self.connected {
             Box::new(
                 self.points
@@ -980,8 +980,8 @@ where
 
         let mut search_tree = collections::binary_heap::BinaryHeap::<PriorityDistance<T>>::new();
         // map from node number to remaining neighbours of that node. All indices of self.points
-        // FnvHashMap::<node_id:usize, (prev_node_id:usize, next_node_id:usize, area:T)>
-        let mut link_tree = fnv::FnvHashMap::<usize, (usize, usize, T)>::default();
+        // AHashMap::<node_id:usize, (prev_node_id:usize, next_node_id:usize, area:T)>
+        let mut link_tree = ahash::AHashMap::<usize, (usize, usize, T)>::default();
         {
             let mut iter_i = self.points.iter().enumerate();
             let mut iter_j = self.points.iter().enumerate().skip(1);
